Ext.namespace('dSS11', 'dSS11.sys');

dSS11.sys.HostNameForm = Ext.extend(Ext.form.FormPanel,
{
    initComponent: function()
    { 
    var sysName =
    {
        xtype: 'fieldset',
        title:  _("Installation name"),
        items:
        [
            {
                xtype: 'label',
                cls: 'x-green-text',
                text: _("Note: the name must not contain any whitespaces" +
                        " and special characters (except '-')")
            },
            {
                xtype: 'box',
                height: 10
            },
            {
                xtype: 'panel',
                layout: 'hbox',
                bodyBorder: false,
                items:
                [
                    {
                        xtype: 'label',
                        text: _("Name") + ':',
                        flex: 1
                    },
                    {
                        xtype: 'box',
                        width: 10
                    },
                    {
                        xtype: 'textfield',
                        width: 220,
                        name: 'hostname',
                        allowBlank: false,
                        maxLength: 64,
                        validator: this.validateHostName
                    },
                    {
                        xtype: 'box',
                        width: 10
                    },
                    {
                        xtype: 'button',
                        text: _("Apply"),
                        minWidth: 90,
                        handler: this.setSystemName.createDelegate(this)
                    }
                ]
            }
        ]
    };

        Ext.apply(this, {
            padding: 6,
            width: 400,
            items: 
            [
                sysName
            ]
        });

        dSS11.sys.HostNameForm.superclass.initComponent.apply(this, arguments);
    },
    setSystemName:  function() {
        if (!this.getForm().isValid()) {
            Ext.Msg.alert(_("Error"), _("The name you entered is invalid! Please do not use any whitespaces or special characters."));
            return;
        }

        this.el.mask(_("Applying changes") + '...', 'x-mask-loading');

        var name = this.getForm().getValues().hostname;

        this.getForm().submit({
            url: '/cgi-bin/setnamewrapper.sh',
            method: 'GET',
            scope: this,
            success: function(form, action) {
                dSS11.util.setApartmentName(name, this.el);
            },
            failure: function(form, action) {
                this.el.unmask();
                switch (action.failureType) {
                    case Ext.form.Action.CONNECT_FAILURE:
                        Ext.Msg.alert(_("Error"),
                            _("Ajax communication failed"));
                    break;
                    default:
                        Ext.Msg.alert(_("Error"),
                                _("Could not save installation name"));
                    break;
                }
            }
        });
    },
    validateHostName: function(name) {
        if ((name.length === 0) || (name.length > 64)) {
            return false;
        }

        var expr = /[^0-9a-zA-Z\-]/;
        if (expr.exec(name) === null) {
            return true;
        }

        return false;
    },
    reloadHostName: function() {
        this.el.mask(_("Loading system name") + "...",
                  'x-mask-loading');
                    
        this.load({
            url: '/cgi-bin/getname.sh',
            method: 'GET',
            scope: this,
            disableCaching: true,
            success: function(form, action) {
                try {
                    var jsonData = Ext.util.JSON.decode(
                                            action.response.responseText);

                    if (jsonData.success !== true) {
                        Ext.Msg.alert(_("Error"), jsonData.message);
                        this.el.unmask();
                        return;
                    }
                } catch (error) {
                    Ext.Msg.alert(_("Error"),
                        _("Could not load installation name") +
                            ": "  + error.message);
                }

                this.el.unmask();
            },
            failure: function(form, action) {
                switch (action.failureType) {
                    case Ext.form.Action.CONNECT_FAILURE:
                        Ext.Msg.alert(_("Error"),
                            _("Ajax communication failed"));
                    break;
                    default:
                        Ext.Msg.alert(_("Error"),
                                _("Could not load installation name"));
                    break;
                }

                this.el.unmask();
            }
        });
    }
});

Ext.reg('dss11syshostnameform', dSS11.sys.HostNameForm);
